@@ -24,6 +24,7 @@ mkdir -p $DC_INSTALL_DIR/plugins/wdx
 mkdir -p $DC_INSTALL_DIR/plugins/wdx/scripts
 mkdir -p $DC_INSTALL_DIR/plugins/wdx/rpm_wdx
 mkdir -p $DC_INSTALL_DIR/plugins/wdx/deb_wdx
+mkdir -p $DC_INSTALL_DIR/plugins/wdx/audioinfo
 # WFX plugins directories
 mkdir -p $DC_INSTALL_DIR/plugins/wfx
 mkdir -p $DC_INSTALL_DIR/plugins/wfx/ftp
@@ -44,13 +45,14 @@ install -m 644 plugins/wcx/cpio/lib/cpio.wcx        $DC_INSTALL_DIR/plugins/wcx/
 install -m 644 plugins/wcx/deb/lib/deb.wcx          $DC_INSTALL_DIR/plugins/wcx/deb/
 install -m 644 plugins/wcx/rpm/lib/rpm.wcx          $DC_INSTALL_DIR/plugins/wcx/rpm/
 install -m 644 plugins/wcx/unrar/lib/unrar.wcx      $DC_INSTALL_DIR/plugins/wcx/unrar/
-install -m 644 plugins/wcx/zip/lib/zip.wcx          $DC_INSTALL_DIR/plugins/wcx/zip/
+install -m 644 plugins/wcx/zip/zip.wcx              $DC_INSTALL_DIR/plugins/wcx/zip/
 # WDX
 install -m 644 plugins/wdx/rpm_wdx/lib/rpm_wdx.wdx  $DC_INSTALL_DIR/plugins/wdx/rpm_wdx/
 install -m 644 plugins/wdx/deb_wdx/lib/deb_wdx.wdx  $DC_INSTALL_DIR/plugins/wdx/deb_wdx/
 install -m 644 plugins/wdx/scripts/*                $DC_INSTALL_DIR/plugins/wdx/scripts/
+install -m 644 plugins/wdx/audioinfo/audioinfo.wdx  $DC_INSTALL_DIR/plugins/wdx/audioinfo/
 # WFX
-install -m 644 plugins/wfx/ftp/lib/ftp.wfx          $DC_INSTALL_DIR/plugins/wfx/ftp/
+install -m 644 plugins/wfx/ftp/ftp.wfx              $DC_INSTALL_DIR/plugins/wfx/ftp/
 
 # Copy documentation
 mkdir -p $DC_INSTALL_DIR/doc
@@ -61,8 +63,9 @@ mkdir -p $DC_INSTALL_DIR/scripts
 cp -a scripts/terminal.sh $DC_INSTALL_DIR/scripts/
 
 # Copy directories
-cp -r language $DC_INSTALL_DIR/
-cp -r pixmaps  $DC_INSTALL_DIR/
+cp -r language     $DC_INSTALL_DIR/
+cp -r pixmaps      $DC_INSTALL_DIR/
+cp -r highlighters $DC_INSTALL_DIR/
 
 # Copy libraries
 cp -a *.dylib             $DC_INSTALL_DIR/
