@@ -3,7 +3,7 @@
 # This script updates Double Commander Open Build Service (OBS) repository
 
 # Set Double Commander version
-DC_VER=0.7.8
+DC_VER=0.8.2
 
 # Temp directory
 DC_TEMP_DIR=/var/tmp/doublecmd-$(date +%y.%m.%d)
@@ -78,6 +78,8 @@ update_doublecmd_svn()
   read -s -p "Enter password: " PASSWORD; echo
   echo "Update Double Commander (Qt)"
   curl -u Alexx2000:$PASSWORD -X POST https://api.opensuse.org/source/home:Alexx2000:doublecmd-svn/doublecmd-qt?cmd=runservice
+  echo "Update Double Commander (Qt5)"
+  curl -u Alexx2000:$PASSWORD -X POST https://api.opensuse.org/source/home:Alexx2000:doublecmd-svn/doublecmd-qt5?cmd=runservice
   echo "Update Double Commander (Gtk)"
   curl -u Alexx2000:$PASSWORD -X POST https://api.opensuse.org/source/home:Alexx2000:doublecmd-svn/doublecmd-gtk?cmd=runservice
   echo "Update Double Commander (Debian)"
